@@ -11,8 +11,8 @@ class EasyEngine(object):
 
 	def __init__(self, host, username=None, password=None, port=None, *args, **kwargs):
 		self._host     = host
-		self._username = username if username or None
-		self._password = password if username or None
+		self._username = username if username else None
+		self._password = password if username else None
 		
 		if port:
 			self._port   = int(port)
